

/*
   orxonox - the future of 3D-vertical-scrollers

   Copyright (C) 2004 orx

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   ### File Specific
   main-programmer: Patrick Boenzli
   co-programmer:
*/


#include "test_bullet.h"

#include "model.h"
#include "vector.h"

using namespace std;


/**
 *  standard constructor
*/
TestBullet::TestBullet (Weapon* weapon) : Projectile(weapon)
{
  this->setClassID(CL_TEST_BULLET, "TestBullet");

  float modelSize = .5;
  this->model = (Model*)ResourceManager::getInstance()->load("models/orx-rocket.obj", OBJ, RP_LEVEL, (void*) &modelSize);
}


/**
 *  standard deconstructor
*/
TestBullet::~TestBullet ()
{
  /*
     do not delete the test projectModel, since it is pnode
     and will be cleaned out by world
  */
  //delete this->projectileModel;
}



/**
 *  signal tick, time dependent things will be handled here
 * @param time since last tick
*/
void TestBullet::tick (float time)
{
  //Vector v = *this->flightDirection * ( this->speed * time * 1000 + 0.1);
  Vector v = this->velocity * (time);
  this->shiftCoor(v);

  this->lifeCycle += time/this->lifeSpan;
  if( this->lifeCycle >= 1)
    {
      PRINTF(5)("FINALIZE==========================\n");
      PRINTF(5)("current life cycle is: %f\n", this->lifeCycle);
      PRINTF(5)("FINALIZE===========================\n");
      this->finalize();
    }
}

/**
 *  the function gets called, when the projectile is destroyed
*/
void TestBullet::destroy ()
{}


void TestBullet::draw ()
{
  glMatrixMode(GL_MODELVIEW);
  glPushMatrix();

  float matrix[4][4];
  glTranslatef (this->getAbsCoor ().x, this->getAbsCoor ().y, this->getAbsCoor ().z);
  this->getAbsDir().matrix (matrix);
  glMultMatrixf((float*)matrix);
  glScalef(2.0, 2.0, 2.0);
  this->model->draw();

  glPopMatrix();
}

